camelot.camelot.model.authentication.Address

Package camelot :: Package camelot :: Package model :: Module authentication :: Class Address |
[hide private]
[frames] | no frames]

# Class Address

source code

Nested Classes | [hide private]
| Admin

Instance Methods | [hide private]
__unicode__(self) | source code
showMap(self) | source code

Class Variables | [hide private]
| street1 = `Field(Unicode(128), required= True)`
| street2 = `Field(Unicode(128))`
| city = `ManyToOne('City', required= True, ondelete= 'cascade', `...``

Class Variable Details | [hide private]

  ### city Value:
      ManyToOne('City', required= True, ondelete= 'cascade', onupdate= 'casc
      ade')